:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/_topologies.py#L500-L745



elpigraph.computeElasticPrincipalCurve
======================================

.. currentmodule:: elpigraph

.. autofunction:: computeElasticPrincipalCurve